[Lldb-commits] [lldb] r157405 - in /lldb/trunk/scripts/Python: build-swig-Python.sh finish-swig-Python-LLDB.sh

Johnny Chen johnny.chen at apple.com
Thu May 24 11:14:18 PDT 2012


Author: johnny
Date: Thu May 24 13:14:18 2012
New Revision: 157405

URL: http://llvm.org/viewvc/llvm-project?rev=157405&view=rev
Log:
Fix missing Resources/Python directory for macosx build.

Modified:
    lldb/trunk/scripts/Python/build-swig-Python.sh
    lldb/trunk/scripts/Python/finish-swig-Python-LLDB.sh

Modified: lldb/trunk/scripts/Python/build-swig-Python.sh
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/scripts/Python/build-swig-Python.sh?rev=157405&r1=157404&r2=157405&view=diff
==============================================================================
--- lldb/trunk/scripts/Python/build-swig-Python.sh (original)
+++ lldb/trunk/scripts/Python/build-swig-Python.sh Thu May 24 13:14:18 2012
@@ -25,7 +25,7 @@
 swig_python_typemaps=${SRC_ROOT}/scripts/Python/python-typemaps.swig
 
 if [ $LLDB_DISABLE_PYTHON = "1" ] ; then
-    # SDKROOT was not empty, which currently means iOS cross build where python is disabled
+    # LLDB_DISABLE_PYTHON is set, which currently means iOS cross build where python is disabled
     rm -rf ${swig_output_file}
     touch ${swig_output_file}
 

Modified: lldb/trunk/scripts/Python/finish-swig-Python-LLDB.sh
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/scripts/Python/finish-swig-Python-LLDB.sh?rev=157405&r1=157404&r2=157405&view=diff
==============================================================================
--- lldb/trunk/scripts/Python/finish-swig-Python-LLDB.sh (original)
+++ lldb/trunk/scripts/Python/finish-swig-Python-LLDB.sh Thu May 24 13:14:18 2012
@@ -33,9 +33,9 @@
 PYTHON_INSTALL_DIR=$4
 debug_flag=$5
 
 # Make sure SDKROOT is not set, since if it is this is an iOS build where python
 # is disabled
-if [ "x$SDKROOT" = "x" ] ; then
+if [ ! $LLDB_DISABLE_PYTHON = "1" ] ; then
 
 if [ -n "$debug_flag" -a "$debug_flag" == "-debug" ]
 then
@@ -33,9 +33,9 @@
 debug_flag=$5
 
-# Make sure SDKROOT is not set, since if it is this is an iOS build where python
+# Make sure LLDB_DISABLE_PYTHON is not set, since if it is this is an iOS build where python
 # is disabled





More information about the lldb-commits mailing list